﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Windows.Controls.Primitives;

namespace ModalPopup
{
    /// <summary>
    /// Copyright © Scientia® Soluciones Informáticas 2009
    /// </summary>
    public static class ModalPopup
    {
        /// <summary>
        /// Muestra un objeto en una ventana modal simulada a través de un <see cref="Popup"/>
        /// </summary>
        /// <param name="Content">Contenido a mostrar en la ventana</param>
        public static Popup Show(UIElement Content)
        {
            //Botón "cerrar"
            Button btnClose = new Button();
            btnClose.Content = new TextBlock() { Text = "Cerrar" };
            btnClose.HorizontalAlignment = HorizontalAlignment.Center;
            btnClose.Margin = new Thickness(0, 10, 0, 0);

            //Grilla para ubicar el contenido y el botón
            Grid objGridContent = new Grid();
            objGridContent.RowDefinitions.Add(new RowDefinition());
            objGridContent.RowDefinitions.Add(new RowDefinition() { Height = GridLength.Auto });
            objGridContent.Children.Add(Content);
            objGridContent.Children.Add(btnClose);
            Grid.SetRow(btnClose, 1);

            //Borde de la ventana
            Border objPopupBorder = new Border();
            objPopupBorder.CornerRadius = new CornerRadius(10);
            objPopupBorder.Background = new SolidColorBrush(Colors.White);
            objPopupBorder.BorderThickness = new Thickness(2);
            objPopupBorder.BorderBrush = new SolidColorBrush(Color.FromArgb(255, 128, 128, 128));
            objPopupBorder.Child = objGridContent;
            objPopupBorder.Padding = new Thickness(10);
            objPopupBorder.Margin = new Thickness(20);
            objPopupBorder.HorizontalAlignment = HorizontalAlignment.Center;
            objPopupBorder.VerticalAlignment = VerticalAlignment.Center;

            //Fondo de la ventana
            Border objBackBorder = new Border();
            objBackBorder.Width = Application.Current.RootVisual.RenderSize.Width;
            objBackBorder.Height = Application.Current.RootVisual.RenderSize.Height;
            objBackBorder.Background = new SolidColorBrush(Color.FromArgb(70, 0, 0, 0));
            objBackBorder.Opacity = 1;
            objBackBorder.Child = objPopupBorder;

            //Popup
            Popup objPopup = new Popup();
            objPopup.Child = objBackBorder;
            ((Application.Current.RootVisual as UserControl).FindName("LayoutRoot") as Grid).Children.Add(objPopup);
            objPopup.Closed += delegate(object sender, EventArgs e)
            {
                //Saco el popup de la grilla
                UIElementCollection objRootElements = ((Application.Current.RootVisual as UserControl).FindName("LayoutRoot") as Grid).Children;
                if (objRootElements.Contains(objPopup))
                    objRootElements.Remove(objPopup);
            };
            objPopup.IsOpen = true;

            //Cerramos el popup al pulsar en el botón
            btnClose.Click += delegate(object sender2, RoutedEventArgs e2) { objPopup.IsOpen = false; };

            //Cambio el tamaño del fondo cuando cambia de tamaño el control
            Application.Current.Host.Content.Resized += delegate(object sender, EventArgs e)
            {
                objBackBorder.Width = Application.Current.RootVisual.RenderSize.Width;
                objBackBorder.Height = Application.Current.RootVisual.RenderSize.Height;
            };


            return objPopup;
        }
    }
}